package com.ruoyi.frequency.platformrules.service;

import java.util.List;
import com.ruoyi.frequency.platformrules.entity.PlatformRules;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 平台规则Service接口
 * 
 * @author liwenlong
 * @date 2024-01-24
 */
public interface PlatformRulesService extends IService<PlatformRules>
{
    /**
     * 查询平台规则
     * 
     * @param id 平台规则主键
     * @return 平台规则
     */
    public PlatformRules selectPlatformRulesById(Long id);

    /**
     * 查询平台规则列表
     * 
     * @param platformRules 平台规则
     * @return 平台规则集合
     */
    public List<PlatformRules> selectPlatformRulesList(PlatformRules platformRules);

    /**
     * 新增平台规则
     * 
     * @param platformRules 平台规则
     * @return 结果
     */
    public int insertPlatformRules(PlatformRules platformRules);

    /**
     * 修改平台规则
     * 
     * @param platformRules 平台规则
     * @return 结果
     */
    public int updatePlatformRules(PlatformRules platformRules);

    /**
     * 批量删除平台规则
     * 
     * @param ids 需要删除的平台规则主键集合
     * @return 结果
     */
    public int deletePlatformRulesByIds(Long[] ids,Integer delFlag);

}
